==> openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.16.1-4.tar.gz: openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.16.1-4/docs/cmd/kn_broker_list.md <==
## kn broker list

List brokers

### Synopsis

List brokers

```
kn broker list
```

### Examples

```

  # List all brokers
  kn broker list

  # List all brokers in JSON output format
  kn broker list -o json
```

### Options

```
  -A, --all-namespaces                If present, list the requested object(s) across all namespaces. Namespace in current context is ignored even if specified with --namespace.
      --allow-missing-template-keys   If true, ignore any errors in templates when a field or map key is missing in the template. Only applies to golang and jsonpath output formats. (default true)
  -h, --help                          help for list
  -n, --namespace string              Specify the namespace to operate in.
      --no-headers                    When using the default output format, don't print headers (default: print headers).
  -o, --output string                 Output format. One of: json|yaml|name|go-template|go-template-file|template|templatefile|jsonpath|jsonpath-file.
      --template string               Template string or path to template file to use when -o=go-template, -o=go-template-file. The template format is golang templates [http://golang.org/pkg/text/template/#pkg-overview].
```

### Options inherited from parent commands

```
      --config string       kn configuration file (default: ~/.config/kn/config.yaml)
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-http            log http traffic
```

### SEE ALSO

* [kn broker](kn_broker.md)	 - Manage message broker

==> openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.18.4-2.tar.gz: openshift-serverless-1-kn-cli-artifacts-rhel8-container-0.18.4-2/docs/cmd/kn_broker_list.md <==
## kn broker list

List brokers (alias: 'ls')

### Synopsis

List brokers (alias: 'ls')

```
kn broker list
```

### Examples

```

  # List all brokers
  kn broker list

  # List all brokers in JSON output format
  kn broker list -o json
```

### Options

```
  -A, --all-namespaces                If present, list the requested object(s) across all namespaces. Namespace in current context is ignored even if specified with --namespace.
      --allow-missing-template-keys   If true, ignore any errors in templates when a field or map key is missing in the template. Only applies to golang and jsonpath output formats. (default true)
  -h, --help                          help for list
  -n, --namespace string              Specify the namespace to operate in.
      --no-headers                    When using the default output format, don't print headers (default: print headers).
  -o, --output string                 Output format. One of: json|yaml|name|go-template|go-template-file|template|templatefile|jsonpath|jsonpath-file.
      --template string               Template string or path to template file to use when -o=go-template, -o=go-template-file. The template format is golang templates [http://golang.org/pkg/text/template/#pkg-overview].
```

### Options inherited from parent commands

```
      --config string       kn configuration file (default: ~/.config/kn/config.yaml)
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-http            log http traffic
```

### SEE ALSO

* [kn broker](kn_broker.md)	 - Manage message broker (alias: brokers)
